onResultInterceptor property
Callback to intercept and decide if the result should be returned
Implementation
final OnResultInterceptorCallback? onResultInterceptor;
Callback to intercept and decide if the result should be returned
final OnResultInterceptorCallback? onResultInterceptor;